@@ -6,4 +6,4 @@ from .job_log import JobLog
 from.job_log_items import JobLogItems
 
 
-db.create_all()
+# db.create_all()
