@@ -4,16 +4,14 @@ import os
 from flask_migrate import Migrate
 from flask_script import Manager, Shell
 from notejob.center.app.core import create_app, db
-from notejob.center.datas.model.cron_infos import CronInfos
-from notejob.center.datas.model.job_log import JobLog
-from notejob.center.datas.model.job_log_items import JobLogItems
+from notejob.center.datas.model import CronInfos, JobLog, JobLogItems
 
 app = create_app(os.getenv('FLASK_CONFIG') or 'default')
 
 manager = Manager(app)
 
 migrate = Migrate(app, db)
-
+db.create_all()
 
 def make_shell_context():
     return dict(
